# P7O6 2D Quadrature rule.
#
#   QUADRULE = P7O6() computes a 7 point Gauss quadrature rule of order 6
#   (exact for all polynomials up to degree 5) on the reference element.
#
#   QUADRULE is a struct containing the following fields:
#    w Weights of the quadrature rule
#    x Abscissae of the quadrature rule (in reference element)
#
#   To recover the barycentric coordinates xbar of the quadrature points
#    xbar = [QuadRule.x, 1-sum(QuadRule.x)'];
#
#   Example:
#
#   QuadRule = P7O6();

#   Copyright 2005-2005 Patrick Meury
#   SAM - Seminar for Applied Mathematics
#   ETH-Zentrum
#   CH-8092 Zurich, Switzerland

from numpy import * 
class QuadRule():
	def __init__(self,w,x):
		self.w = w
		self.x = x


def P7O6():
	w = array([[9/80.],[(155+sqrt(15))/2400.],[(155+sqrt(15))/2400.],[(155+sqrt(15))/2400.],[(155-sqrt(15))/2400.],[(155-sqrt(15))/2400.],[(155-sqrt(15))/2400.] ])
	x = array([[1/3.,1/3.],[(6+sqrt(15))/21.,(6+sqrt(15))/21.],[(9-2*sqrt(15))/21.,(6+sqrt(15))/21.], [(6+sqrt(15))/21.,(9-2*sqrt(15))/21.], [(6-sqrt(15))/21.,(9+2*sqrt(15))/21.],[(9+2*sqrt(15))/21.,(6-sqrt(15))/21.],[(6-sqrt(15))/21.,(6-sqrt(15))/21.]])
	p7o6 = QuadRule(w,x)
	return p7o6
	
